# Triton Inference Server Middleware
Simple middleware that serve APIs for Triton Inference Server.
## License
[GNU AGPL v3.0](LICENSE).<br>
Copyright &copy; 2024 [Hieu Pham](https://github.com/hieupth). All rights reserved.